======================
Dusty-Evolved-Star-Kit
======================


.. image:: https://img.shields.io/pypi/v/desk.svg
        :target: https://pypi.python.org/pypi/desk

.. image:: https://travis-ci.org/s-goldman/Dusty-Evolved-Star-Kit.svg?branch=master
        :target: https://travis-ci.org/s-goldman/Dusty-Evolved-Star-Kit

.. image:: https://readthedocs.org/projects/dusty-evolved-star-kit/badge/?version=latest
        :target: https://dusty-evolved-star-kit.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




The DESK is an SED-fitting python scripts for fitting data from evolved stars


* Free software: BSD license
* Documentation: https://dusty-evolved-star-kit.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
